"""Raw representations of every data type in the AWS Budgets service.

See Also:
    `AWS developer guide for Budgets
    <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "Budget",
    "BudgetProperties",
]


@attrs(**ATTRSCONFIG)
class BudgetProperties(ResourceProperties):
    Budget = attrib(default=None)
    NotificationsWithSubscribers = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Budget(Resource):
    """A Budget for Budgets.

    See Also:
        `AWS Cloud Formation documentation for Budget
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budget.html>`_
    """

    RESOURCE_TYPE = "AWS::Budgets::Budget"

    Properties: BudgetProperties = attrib(
        factory=BudgetProperties,
        converter=create_object_converter(BudgetProperties),
    )
