"""General-use classes to interact with the CertificateManager service through CloudFormation.

See Also:
    `AWS developer guide for CertificateManager
    <https://docs.aws.amazon.com/acm/latest/userguide/acm-overview.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import certificatemanager as _raw

# noinspection PyUnresolvedReferences
from .._raw.certificatemanager import *
