"""General-use classes to interact with the AppStream service through CloudFormation.

See Also:
    `AWS developer guide for AppStream
    <https://docs.aws.amazon.com/appstream2/latest/developerguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import appstream as _raw

# noinspection PyUnresolvedReferences
from .._raw.appstream import *
