"""General-use classes to interact with the DLM service through CloudFormation.

See Also:
    `AWS developer guide for DLM
    <https://docs.aws.amazon.com/dlm/latest/APIReference/Welcome.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import dlm as _raw

# noinspection PyUnresolvedReferences
from .._raw.dlm import *
