"""General-use classes to interact with the IoT1Click service through CloudFormation.

See Also:
    `AWS developer guide for IoT1Click
    <https://docs.aws.amazon.com/iot-1-click/latest/developerguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import iot1click as _raw

# noinspection PyUnresolvedReferences
from .._raw.iot1click import *
