"""General-use classes to interact with the Cloud9 service through CloudFormation.

See Also:
    `AWS developer guide for Cloud9
    <https://docs.aws.amazon.com/cloud9/latest/user-guide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import cloud9 as _raw

# noinspection PyUnresolvedReferences
from .._raw.cloud9 import *
