"""Raw representations of every data type in the AWS Athena service.

See Also:
    `AWS developer guide for Athena
    <https://docs.aws.amazon.com/athena/latest/ug/what-is.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "NamedQuery",
    "NamedQueryProperties",
]


@attrs(**ATTRSCONFIG)
class NamedQueryProperties(ResourceProperties):
    Database = attrib(default=None)
    Description = attrib(default=None)
    Name = attrib(default=None)
    QueryString = attrib(default=None)


@attrs(**ATTRSCONFIG)
class NamedQuery(Resource):
    """A Named Query for Athena.

    See Also:
        `AWS Cloud Formation documentation for NamedQuery
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html>`_
    """

    RESOURCE_TYPE = "AWS::Athena::NamedQuery"

    Properties: NamedQueryProperties = attrib(
        factory=NamedQueryProperties,
        converter=create_object_converter(NamedQueryProperties),
    )
