"""General-use classes to interact with the ApplicationAutoScaling service through CloudFormation.

See Also:
    `AWS developer guide for ApplicationAutoScaling
    <https://docs.aws.amazon.com/autoscaling/application/APIReference/Welcome.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import applicationautoscaling as _raw

# noinspection PyUnresolvedReferences
from .._raw.applicationautoscaling import *
