"""General-use classes to interact with the AmazonMQ service through CloudFormation.

See Also:
    `AWS developer guide for AmazonMQ
    <https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/welcome.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import amazonmq as _raw

# noinspection PyUnresolvedReferences
from .._raw.amazonmq import *
