"""General-use classes to interact with the GameLift service through CloudFormation.

See Also:
    `AWS developer guide for GameLift
    <https://docs.aws.amazon.com/gamelift/latest/developerguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import gamelift as _raw

# noinspection PyUnresolvedReferences
from .._raw.gamelift import *
