"""General-use classes to interact with the ServiceCatalog service through CloudFormation.

See Also:
    `AWS developer guide for ServiceCatalog
    <https://docs.aws.amazon.com/servicecatalog/latest/dg/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import servicecatalog as _raw

# noinspection PyUnresolvedReferences
from .._raw.servicecatalog import *
