"""Raw representations of every data type in the AWS Cloud9 service.

See Also:
    `AWS developer guide for Cloud9
    <https://docs.aws.amazon.com/cloud9/latest/user-guide/index.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "EnvironmentEC2",
    "EnvironmentEC2Properties",
]


@attrs(**ATTRSCONFIG)
class EnvironmentEC2Properties(ResourceProperties):
    AutomaticStopTimeMinutes = attrib(default=None)
    Description = attrib(default=None)
    InstanceType = attrib(default=None)
    Name = attrib(default=None)
    OwnerArn = attrib(default=None)
    Repositories = attrib(default=None)
    SubnetId = attrib(default=None)


@attrs(**ATTRSCONFIG)
class EnvironmentEC2(Resource):
    """A Environment Ec2 for Cloud9.

    See Also:
        `AWS Cloud Formation documentation for EnvironmentEC2
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html>`_
    """

    RESOURCE_TYPE = "AWS::Cloud9::EnvironmentEC2"

    Properties: EnvironmentEC2Properties = attrib(
        factory=EnvironmentEC2Properties,
        converter=create_object_converter(EnvironmentEC2Properties),
    )
