"""General-use classes to interact with the FSx service through CloudFormation.

See Also:
    `AWS developer guide for FSx
    <https://docs.aws.amazon.com/fsx/latest/WindowsGuide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import fsx as _raw

# noinspection PyUnresolvedReferences
from .._raw.fsx import *
