"""General-use classes to interact with the KinesisFirehose service through CloudFormation.

See Also:
    `AWS developer guide for KinesisFirehose
    <https://docs.aws.amazon.com/firehose/latest/dev/what-is-this-service.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import kinesisfirehose as _raw

# noinspection PyUnresolvedReferences
from .._raw.kinesisfirehose import *
