"""General-use classes to interact with the DirectoryService service through CloudFormation.

See Also:
    `AWS developer guide for DirectoryService
    <https://docs.aws.amazon.com/directoryservice/latest/admin-guide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import directoryservice as _raw

# noinspection PyUnresolvedReferences
from .._raw.directoryservice import *
