"""General-use classes to interact with the IoT service through CloudFormation.

See Also:
    `AWS developer guide for IoT
    <https://docs.aws.amazon.com/iot/latest/developerguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import iot as _raw

# noinspection PyUnresolvedReferences
from .._raw.iot import *
