"""General-use classes to interact with the RAM service through CloudFormation.

See Also:
    `AWS developer guide for RAM
    <https://docs.aws.amazon.com/ram/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import ram as _raw

# noinspection PyUnresolvedReferences
from .._raw.ram import *
