"""General-use classes to interact with the CodeBuild service through CloudFormation.

See Also:
    `AWS developer guide for CodeBuild
    <https://docs.aws.amazon.com/codebuild/latest/userguide/welcome.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import codebuild as _raw

# noinspection PyUnresolvedReferences
from .._raw.codebuild import *
