"""Raw representations of every data type in the AWS DAX service.

See Also:
    `AWS developer guide for DAX
    <https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/DAX.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "Cluster",
    "ClusterProperties",
    "ParameterGroup",
    "ParameterGroupProperties",
    "SubnetGroup",
    "SubnetGroupProperties",
]


@attrs(**ATTRSCONFIG)
class ClusterProperties(ResourceProperties):
    AvailabilityZones = attrib(default=None)
    ClusterName = attrib(default=None)
    Description = attrib(default=None)
    IAMRoleARN = attrib(default=None)
    NodeType = attrib(default=None)
    NotificationTopicARN = attrib(default=None)
    ParameterGroupName = attrib(default=None)
    PreferredMaintenanceWindow = attrib(default=None)
    ReplicationFactor = attrib(default=None)
    SecurityGroupIds = attrib(default=None)
    SSESpecification = attrib(default=None)
    SubnetGroupName = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Cluster(Resource):
    """A Cluster for DAX.

    See Also:
        `AWS Cloud Formation documentation for Cluster
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html>`_
    """

    RESOURCE_TYPE = "AWS::DAX::Cluster"

    Properties: ClusterProperties = attrib(
        factory=ClusterProperties,
        converter=create_object_converter(ClusterProperties),
    )


@attrs(**ATTRSCONFIG)
class ParameterGroupProperties(ResourceProperties):
    Description = attrib(default=None)
    ParameterGroupName = attrib(default=None)
    ParameterNameValues = attrib(default=None)


@attrs(**ATTRSCONFIG)
class ParameterGroup(Resource):
    """A Parameter Group for DAX.

    See Also:
        `AWS Cloud Formation documentation for ParameterGroup
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html>`_
    """

    RESOURCE_TYPE = "AWS::DAX::ParameterGroup"

    Properties: ParameterGroupProperties = attrib(
        factory=ParameterGroupProperties,
        converter=create_object_converter(ParameterGroupProperties),
    )


@attrs(**ATTRSCONFIG)
class SubnetGroupProperties(ResourceProperties):
    Description = attrib(default=None)
    SubnetGroupName = attrib(default=None)
    SubnetIds = attrib(default=None)


@attrs(**ATTRSCONFIG)
class SubnetGroup(Resource):
    """A Subnet Group for DAX.

    See Also:
        `AWS Cloud Formation documentation for SubnetGroup
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html>`_
    """

    RESOURCE_TYPE = "AWS::DAX::SubnetGroup"

    Properties: SubnetGroupProperties = attrib(
        factory=SubnetGroupProperties,
        converter=create_object_converter(SubnetGroupProperties),
    )
