"""Raw representations of every data type in the AWS KinesisAnalytics service.

See Also:
    `AWS developer guide for KinesisAnalytics
    <https://docs.aws.amazon.com/kinesisanalytics/latest/dev/what-is.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "Application",
    "ApplicationProperties",
    "ApplicationOutput",
    "ApplicationOutputProperties",
    "ApplicationReferenceDataSource",
    "ApplicationReferenceDataSourceProperties",
]


@attrs(**ATTRSCONFIG)
class ApplicationProperties(ResourceProperties):
    ApplicationCode = attrib(default=None)
    ApplicationDescription = attrib(default=None)
    ApplicationName = attrib(default=None)
    Inputs = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Application(Resource):
    """A Application for KinesisAnalytics.

    See Also:
        `AWS Cloud Formation documentation for Application
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesisanalytics-application.html>`_
    """

    RESOURCE_TYPE = "AWS::KinesisAnalytics::Application"

    Properties: ApplicationProperties = attrib(
        factory=ApplicationProperties,
        converter=create_object_converter(ApplicationProperties),
    )


@attrs(**ATTRSCONFIG)
class ApplicationOutputProperties(ResourceProperties):
    ApplicationName = attrib(default=None)
    Output = attrib(default=None)


@attrs(**ATTRSCONFIG)
class ApplicationOutput(Resource):
    """A Application Output for KinesisAnalytics.

    See Also:
        `AWS Cloud Formation documentation for ApplicationOutput
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesisanalytics-applicationoutput.html>`_
    """

    RESOURCE_TYPE = "AWS::KinesisAnalytics::ApplicationOutput"

    Properties: ApplicationOutputProperties = attrib(
        factory=ApplicationOutputProperties,
        converter=create_object_converter(ApplicationOutputProperties),
    )


@attrs(**ATTRSCONFIG)
class ApplicationReferenceDataSourceProperties(ResourceProperties):
    ApplicationName = attrib(default=None)
    ReferenceDataSource = attrib(default=None)


@attrs(**ATTRSCONFIG)
class ApplicationReferenceDataSource(Resource):
    """A Application Reference Data Source for KinesisAnalytics.

    See Also:
        `AWS Cloud Formation documentation for ApplicationReferenceDataSource
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesisanalytics-applicationreferencedatasource.html>`_
    """

    RESOURCE_TYPE = "AWS::KinesisAnalytics::ApplicationReferenceDataSource"

    Properties: ApplicationReferenceDataSourceProperties = attrib(
        factory=ApplicationReferenceDataSourceProperties,
        converter=create_object_converter(ApplicationReferenceDataSourceProperties),
    )
