"""Raw representations of every data type in the AWS DLM service.

See Also:
    `AWS developer guide for DLM
    <https://docs.aws.amazon.com/dlm/latest/APIReference/Welcome.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "LifecyclePolicy",
    "LifecyclePolicyProperties",
]


@attrs(**ATTRSCONFIG)
class LifecyclePolicyProperties(ResourceProperties):
    Description = attrib(default=None)
    ExecutionRoleArn = attrib(default=None)
    PolicyDetails = attrib(default=None)
    State = attrib(default=None)


@attrs(**ATTRSCONFIG)
class LifecyclePolicy(Resource):
    """A Lifecycle Policy for DLM.

    See Also:
        `AWS Cloud Formation documentation for LifecyclePolicy
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html>`_
    """

    RESOURCE_TYPE = "AWS::DLM::LifecyclePolicy"

    Properties: LifecyclePolicyProperties = attrib(
        factory=LifecyclePolicyProperties,
        converter=create_object_converter(LifecyclePolicyProperties),
    )
