"""General-use classes to interact with the Inspector service through CloudFormation.

See Also:
    `AWS developer guide for Inspector
    <https://docs.aws.amazon.com/inspector/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import inspector as _raw

# noinspection PyUnresolvedReferences
from .._raw.inspector import *
