"""General-use classes to interact with the Config service through CloudFormation.

See Also:
    `AWS developer guide for Config
    <https://docs.aws.amazon.com/config/latest/developerguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import config as _raw

# noinspection PyUnresolvedReferences
from .._raw.config import *
