"""General-use classes to interact with the ElasticBeanstalk service through CloudFormation.

See Also:
    `AWS developer guide for ElasticBeanstalk
    <https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import elasticbeanstalk as _raw

# noinspection PyUnresolvedReferences
from .._raw.elasticbeanstalk import *
