"""General-use classes to interact with the IoTAnalytics service through CloudFormation.

See Also:
    `AWS developer guide for IoTAnalytics
    <https://docs.aws.amazon.com/appsync/latest/devguide/welcome.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import iotanalytics as _raw

# noinspection PyUnresolvedReferences
from .._raw.iotanalytics import *
