"""General-use classes to interact with the Glue service through CloudFormation.

See Also:
    `AWS developer guide for Glue
    <https://docs.aws.amazon.com/glue/latest/dg/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import glue as _raw

# noinspection PyUnresolvedReferences
from .._raw.glue import *
