"""General-use classes to interact with the ApiGateway service through CloudFormation.

See Also:
    `AWS developer guide for ApiGateway
    <https://docs.aws.amazon.com/apigateway/latest/developerguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import apigateway as _raw

# noinspection PyUnresolvedReferences
from .._raw.apigateway import *
