"""General-use classes to interact with the CodeDeploy service through CloudFormation.

See Also:
    `AWS developer guide for CodeDeploy
    <https://docs.aws.amazon.com/codedeploy/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import codedeploy as _raw

# noinspection PyUnresolvedReferences
from .._raw.codedeploy import *
