"""General-use classes to interact with the WorkSpaces service through CloudFormation.

See Also:
    `AWS developer guide for WorkSpaces
    <https://docs.aws.amazon.com/workspaces/latest/adminguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import workspaces as _raw

# noinspection PyUnresolvedReferences
from .._raw.workspaces import *
