"""General-use classes to interact with the CodePipeline service through CloudFormation.

See Also:
    `AWS developer guide for CodePipeline
    <https://docs.aws.amazon.com/codepipeline/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import codepipeline as _raw

# noinspection PyUnresolvedReferences
from .._raw.codepipeline import *
