"""General-use classes to interact with the Budgets service through CloudFormation.

See Also:
    `AWS developer guide for Budgets
    <https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import budgets as _raw

# noinspection PyUnresolvedReferences
from .._raw.budgets import *
