"""General-use classes to interact with the Logs service through CloudFormation.

See Also:
    `AWS developer guide for Logs
    <https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import logs as _raw

# noinspection PyUnresolvedReferences
from .._raw.logs import *
