"""General-use classes to interact with the OpsWorksCM service through CloudFormation.

See Also:
    `AWS developer guide for OpsWorksCM
    <https://docs.aws.amazon.com/opsworks/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import opsworkscm as _raw

# noinspection PyUnresolvedReferences
from .._raw.opsworkscm import *
