"""General-use classes to interact with the KinesisAnalyticsV2 service through CloudFormation.

See Also:
    `AWS developer guide for KinesisAnalyticsV2
    <https://docs.aws.amazon.com/kinesisanalytics/latest/java/what-is.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import kinesisanalyticsv2 as _raw

# noinspection PyUnresolvedReferences
from .._raw.kinesisanalyticsv2 import *
