"""General-use classes to interact with the RoboMaker service through CloudFormation.

See Also:
    `AWS developer guide for RoboMaker
    <https://docs.aws.amazon.com/robomaker/latest/dg/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import robomaker as _raw

# noinspection PyUnresolvedReferences
from .._raw.robomaker import *
