"""General-use classes to interact with the CodeCommit service through CloudFormation.

See Also:
    `AWS developer guide for CodeCommit
    <https://docs.aws.amazon.com/codecommit/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import codecommit as _raw

# noinspection PyUnresolvedReferences
from .._raw.codecommit import *
