"""General-use classes to interact with the Events service through CloudFormation.

See Also:
    `AWS developer guide for Events
    <https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/WhatIsCloudWatchEvents.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import events as _raw

# noinspection PyUnresolvedReferences
from .._raw.events import *
