"""General-use classes to interact with the ServiceDiscovery service through CloudFormation.

See Also:
    `AWS developer guide for ServiceDiscovery
    <https://docs.aws.amazon.com/cloud-map/latest/dg/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import servicediscovery as _raw

# noinspection PyUnresolvedReferences
from .._raw.servicediscovery import *
