"""General-use classes to interact with the OpsWorks service through CloudFormation.

See Also:
    `AWS developer guide for OpsWorks
    <https://docs.aws.amazon.com/opsworks/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import opsworks as _raw

# noinspection PyUnresolvedReferences
from .._raw.opsworks import *
