"""General-use classes to interact with the KinesisAnalytics service through CloudFormation.

See Also:
    `AWS developer guide for KinesisAnalytics
    <https://docs.aws.amazon.com/kinesisanalytics/latest/dev/what-is.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import kinesisanalytics as _raw

# noinspection PyUnresolvedReferences
from .._raw.kinesisanalytics import *
