"""General-use classes to interact with the AutoScalingPlans service through CloudFormation.

See Also:
    `AWS developer guide for AutoScalingPlans
    <https://docs.aws.amazon.com/autoscaling/plans/userguide/>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import autoscalingplans as _raw

# noinspection PyUnresolvedReferences
from .._raw.autoscalingplans import *
