"""General-use classes to interact with the ApiGatewayV2 service through CloudFormation.

See Also:
    `AWS developer guide for ApiGatewayV2
    <https://docs.aws.amazon.com/apigateway/latest/developerguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import apigatewayv2 as _raw

# noinspection PyUnresolvedReferences
from .._raw.apigatewayv2 import *
