"""General-use classes to interact with the CloudTrail service through CloudFormation.

See Also:
    `AWS developer guide for CloudTrail
    <https://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-user-guide.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import cloudtrail as _raw

# noinspection PyUnresolvedReferences
from .._raw.cloudtrail import *
