"""General-use classes to interact with the DocDB service through CloudFormation.

See Also:
    `AWS developer guide for DocDB
    <https://docs.aws.amazon.com/documentdb/latest/developerguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import docdb as _raw

# noinspection PyUnresolvedReferences
from .._raw.docdb import *
